@@ -1,5 +1,3 @@
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -7,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifndef GVPLUGIN_IMAGELOAD_H
@@ -22,27 +20,28 @@ extern "C" {
 #endif
 
 #ifdef GVDLL
-#  define extern __declspec(dllexport)
+#  define GVPLUGIN_LOADIMAGE_API __declspec(dllexport)
 #endif
 
 /*visual studio*/
 #ifdef _WIN32
 #ifndef GVC_EXPORTS
-#define extern __declspec(dllimport)
+#define GVPLUGIN_LOADIMAGE_API __declspec(dllimport)
 #endif
 #endif
 /*end visual studio*/
+#ifndef GVPLUGIN_LOADIMAGE_API
+#define GVPLUGIN_LOADIMAGE_API extern
+#endif
 
-extern boolean gvusershape_file_access(usershape_t *us);
-extern void gvusershape_file_release(usershape_t *us);
+GVPLUGIN_LOADIMAGE_API boolean gvusershape_file_access(usershape_t *us);
+GVPLUGIN_LOADIMAGE_API void gvusershape_file_release(usershape_t *us);
 
     struct gvloadimage_engine_s {
 	void (*loadimage) (GVJ_t *job, usershape_t *us, boxf b, boolean filled);
     };
 
-#ifdef extern
-#undef extern
-#endif
+#undef GVPLUGIN_LOADIMAGE_API
 
 #ifdef __cplusplus
 }
